@@ -792,17 +792,42 @@ TEST_P(SpirvReflectTest, CheckYamlOutput) {
 }
 
 namespace {
+// TODO - have this glob search all .spv files
 const std::vector<const char*> all_spirv_paths = {
     // clang-format off
+    "../tests/16bit/vert_in_out_16.spv",
     "../tests/access_chains/array_length_from_access_chain.spv",
+    "../tests/access_chains/pointer_access_chain_phy_storage_buffer.spv",
     "../tests/cbuffer_unused/cbuffer_unused_001.spv",
     "../tests/glsl/built_in_format.spv",
+    "../tests/entry_exec_mode/comp_local_size.spv",
+    "../tests/entry_exec_mode/geom_inv_out_vert.spv",
+    "../tests/execution_mode/local_size_id_spec.spv",
+    "../tests/execution_mode/local_size_id.spv",
+    "../tests/glsl/buffer_handle_0.spv",
+    "../tests/glsl/buffer_handle_1.spv",
+    "../tests/glsl/buffer_handle_2.spv",
+    "../tests/glsl/buffer_handle_3.spv",
+    "../tests/glsl/buffer_handle_4.spv",
+    "../tests/glsl/buffer_handle_5.spv",
+    "../tests/glsl/buffer_handle_6.spv",
+    "../tests/glsl/buffer_handle_7.spv",
+    "../tests/glsl/buffer_handle_8.spv",
+    "../tests/glsl/buffer_handle_9.spv",
+    "../tests/glsl/buffer_handle_uvec2_pc.spv",
+    "../tests/glsl/buffer_handle_uvec2_ssbo.spv",
     "../tests/glsl/buffer_pointer.spv",
+    "../tests/glsl/built_in_format.spv",
     "../tests/glsl/fn_struct_param.spv",
+    "../tests/glsl/frag_array_input.spv",
+    "../tests/glsl/frag_barycentric.spv",
     "../tests/glsl/input_attachment.spv",
     "../tests/glsl/io_vars_vs.spv",
     "../tests/glsl/matrix_major_order_glsl.spv",
+    "../tests/glsl/non_writable_image.spv",
+    "../tests/glsl/readonly_writeonly.spv",
     "../tests/glsl/runtime_array_of_array_of_struct.spv",
+    "../tests/glsl/storage_buffer.spv",
     "../tests/glsl/texel_buffer.spv",
     "../tests/hlsl/append_consume.spv",
     "../tests/hlsl/array_of_structured_buffer.spv",
@@ -817,12 +842,27 @@ const std::vector<const char*> all_spirv_paths = {
     "../tests/hlsl/pushconstant.spv",
     "../tests/hlsl/semantics.spv",
     "../tests/hlsl/structuredbuffer.spv",
+    "../tests/hlsl/user_type.spv",
+    "../tests/interface/geom_input_builtin_array.spv",
+    "../tests/interface/vertex_input_builtin_block.spv",
+    "../tests/interface/vertex_input_builtin_non_block.spv",
     "../tests/issues/77/hlsl/array_from_ubo.spv",
     "../tests/issues/77/hlsl/array_from_ubo_with_O0.spv",
     "../tests/issues/77/hlsl/rocketz.spv",
+    "../tests/issues/102/function_parameter_access.spv",
     "../tests/issues/178/vertex_input_struct.spv",
     "../tests/issues/178/vertex_input_struct2.spv",
+    "../tests/issues/227/null_node.spv",
+    "../tests/mesh_shader_ext/mesh_shader_ext.task.hlsl.spv",
+    "../tests/mesh_shader_ext/mesh_shader_ext.mesh.hlsl.spv",
     "../tests/multi_entrypoint/multi_entrypoint.spv",
+    "../tests/push_constants/non_zero_block_offset.spv",
+    "../tests/push_constants/pointer_in_struct.spv",
+    "../tests/push_constants/pointer_in_struct_2.spv",
+    "../tests/push_constants/push_constant_basic_0.spv",
+    "../tests/push_constants/push_constant_basic_1.spv",
+    "../tests/push_constants/push_constant_basic_2.spv",
+    "../tests/push_constants/push_constant_basic_3.spv",
     "../tests/raytrace/rayquery_equal.cs.spv",
     "../tests/raytrace/rayquery_init_ds.spv",
     "../tests/raytrace/rayquery_init_gs.spv",
@@ -844,9 +884,34 @@ const std::vector<const char*> all_spirv_paths = {
     "../tests/raytrace/raytracing.nv.library.spv",
     "../tests/raytrace/raytracing.nv.miss.spv",
     "../tests/raytrace/raytracing.nv.raygen.spv",
+    "../tests/spec_constants/basic.spv",
+    "../tests/spec_constants/convert.spv",
+    "../tests/spec_constants/local_size_id_10.spv",
+    "../tests/spec_constants/local_size_id_13.spv",
+    "../tests/spec_constants/ssbo_array.spv",
+    "../tests/spec_constants/test_32bit.spv",
+    "../tests/spec_constants/test_64bit.spv",
     "../tests/spirv15/VertexShader.spv",
-    "../tests/mesh_shader_ext/mesh_shader_ext.task.hlsl.spv",
-    "../tests/mesh_shader_ext/mesh_shader_ext.mesh.hlsl.spv",
+    "../tests/user_type/byte_address_buffer_0.spv",
+    "../tests/user_type/byte_address_buffer_1.spv",
+    "../tests/user_type/byte_address_buffer_2.spv",
+    "../tests/user_type/byte_address_buffer_3.spv",
+    "../tests/user_type/rw_byte_address_buffer.spv",
+    "../tests/variable_access/atomics_0.spv",
+    "../tests/variable_access/atomics_1.spv",
+    "../tests/variable_access/copy_array_0.spv",
+    "../tests/variable_access/copy_array_1.spv",
+    "../tests/variable_access/copy_array_2.spv",
+    "../tests/variable_access/copy_array_3.spv",
+    "../tests/variable_access/copy_memory.spv",
+    "../tests/variable_access/copy_struct_0.spv",
+    "../tests/variable_access/copy_struct_1.spv",
+    "../tests/variable_access/descriptor_indexing_0.spv",
+    "../tests/variable_access/descriptor_indexing_1.spv",
+    "../tests/variable_access/phy_storage_buffer_used_0.spv",
+    "../tests/variable_access/phy_storage_buffer_used_1.spv",
+    "../tests/variable_access/phy_storage_buffer_used_2.spv",
+    "../tests/variable_access/phy_storage_buffer_used_3.spv",
     // clang-format on
 };
 }  // namespace
